==> 1.3.4.tar.gz: doc/World.md <==
# vrchat_dart_generated.model.World

## Load the model package
```dart
import 'package:vrchat_dart_generated/api.dart';
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**assetUrl** | **String** |  | 
**assetUrlObject** | [**JsonObject**](.md) |  | 
**authorId** | **String** |  | 
**authorName** | **String** |  | 
**capacity** | **num** |  | 
**createdAt** | [**DateTime**](DateTime.md) |  | 
**description** | **String** |  | 
**favorites** | **num** |  | [optional] [default to 0]
**featured** | **bool** |  | [default to false]
**heat** | **num** |  | [default to 0]
**id** | **String** |  | 
**imageUrl** | **String** |  | 
**instances** | [**BuiltList&lt;JsonObject&gt;**](JsonObject.md) |  | [optional] 
**labsPublicationDate** | **String** |  | 
**name** | **String** |  | 
**namespace** | **String** |  | 
**occupants** | **num** |  | [optional] [default to 0]
**organization** | **String** |  | [default to 'vrchat']
**pluginUrlObject** | [**JsonObject**](.md) |  | 
**popularity** | **num** |  | [default to 0]
**previewYoutubeId** | **String** |  | [optional] 
**privateOccupants** | **num** |  | [optional] [default to 0]
**publicOccupants** | **num** |  | [optional] [default to 0]
**publicationDate** | [**DateTime**](DateTime.md) |  | 
**releaseStatus** | [**ReleaseStatus**](ReleaseStatus.md) |  | 
**tags** | **BuiltList&lt;String&gt;** |  | 
**thumbnailImageUrl** | **String** |  | 
**unityPackageUrlObject** | [**JsonObject**](.md) |  | 
**unityPackages** | [**BuiltSet&lt;UnityPackage&gt;**](UnityPackage.md) |  | 
**updatedAt** | [**DateTime**](DateTime.md) |  | 
**version** | **num** |  | [default to 0]
**visits** | **num** |  | [default to 0]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> 1.3.7.tar.gz: doc/World.md <==
# vrchat_dart_generated.model.World

## Load the model package
```dart
import 'package:vrchat_dart_generated/api.dart';
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**assetUrl** | **String** |  | 
**assetUrlObject** | [**JsonObject**](.md) |  | 
**authorId** | **String** |  | 
**authorName** | **String** |  | 
**capacity** | **num** |  | 
**createdAt** | [**DateTime**](DateTime.md) |  | 
**description** | **String** |  | 
**favorites** | **num** |  | [optional] [default to 0]
**featured** | **bool** |  | [default to false]
**heat** | **num** |  | [default to 0]
**id** | **String** |  | 
**imageUrl** | **String** |  | 
**instances** | [**BuiltList&lt;BuiltList&lt;JsonObject&gt;&gt;**](BuiltList.md) |  | [optional] 
**labsPublicationDate** | **String** |  | 
**name** | **String** |  | 
**namespace** | **String** |  | 
**occupants** | **num** |  | [optional] [default to 0]
**organization** | **String** |  | [default to 'vrchat']
**pluginUrlObject** | [**JsonObject**](.md) |  | 
**popularity** | **num** |  | [default to 0]
**previewYoutubeId** | **String** |  | [optional] 
**privateOccupants** | **num** |  | [optional] [default to 0]
**publicOccupants** | **num** |  | [optional] [default to 0]
**publicationDate** | [**DateTime**](DateTime.md) |  | 
**releaseStatus** | [**ReleaseStatus**](ReleaseStatus.md) |  | 
**tags** | **BuiltList&lt;String&gt;** |  | 
**thumbnailImageUrl** | **String** |  | 
**unityPackageUrlObject** | [**JsonObject**](.md) |  | 
**unityPackages** | [**BuiltList&lt;UnityPackage&gt;**](UnityPackage.md) |  | 
**updatedAt** | [**DateTime**](DateTime.md) |  | 
**version** | **num** |  | [default to 0]
**visits** | **num** |  | [default to 0]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
